@@ -700,6 +700,21 @@ class CollectionModelTestCase(unittest.TestCase):
 
         TestModel.destroy()
 
+    def test_get_model_key_and_id_directly(self):
+
+        class TestModel(CollectionModel):
+            collection_name = "test_model"
+
+        TestModel.init()
+
+        model = TestModel()
+        model.save()
+
+        self.assertEqual(model.key, model.document.key)
+        self.assertEqual(model.id, model.document.id)
+
+        TestModel.destroy()
+
     def test_save_model_with_one_field_not_required(self):
 
         class TestModel(CollectionModel):
@@ -1297,6 +1312,15 @@ class ForeignkeyFieldTestCase(unittest.TestCase):
 
         self.assertEqual(field1, field2)
 
+    def test_model_loading(self):
+
+        model = ForeignkeyFieldTestCase.TestModel()
+
+        field1 = ForeignKeyField(to=ForeignkeyFieldTestCase.TestModel)
+        field1.loads(model)
+
+        self.assertEqual(field1.relation_model, model)
+
 
 class ManyToManyFieldTestCase(unittest.TestCase):
 
